==> univention-directory-reports_12.0.3-2A~5.0.0.202302061627.tar.gz: univention-directory-reports-12.0.3/modules/univention/directory/reports/__init__.py <==
# -*- coding: utf-8 -*-
#
# Univention Directory Reports
#  module for creating reports about any kind of Univention Admin object
#
# Like what you see? Join us!
# https://www.univention.com/about-us/careers/vacancies/
#
# Copyright 2007-2023 Univention GmbH
#
# https://www.univention.de/
#
# All rights reserved.
#
# The source code of this program is made available
# under the terms of the GNU Affero General Public License version 3
# (GNU AGPL V3) as published by the Free Software Foundation.
#
# Binary versions of this program provided by Univention to you as
# well as other copyrighted, protected or trademarked materials like
# Logos, graphics, fonts, specific documentations and configurations,
# cryptographic keys etc. are subject to a license agreement between
# you and Univention and not subject to the GNU AGPL V3.
#
# In the case you use this program under the terms of the GNU AGPL V3,
# the program is provided in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License with the Debian GNU/Linux or Univention distribution in file
# /usr/share/common-licenses/AGPL-3; if not, see
# <https://www.gnu.org/licenses/>.


from univention.directory.reports.admin import cache_object, connect, connected, get_object, identify, set_format
from univention.directory.reports.config import Config
from univention.directory.reports.document import Document
from univention.directory.reports.error import ReportError
from univention.directory.reports.report import Report


__all__ = ['Report', 'ReportError', 'Document', 'connect', 'get_object', 'cache_object', 'connected', 'identify', 'set_format', 'Config']

==> univention-directory-reports_13.0.1A~5.1.0.202402201104.tar.gz: univention-directory-reports-13.0.1/modules/univention/directory/reports/__init__.py <==
# -*- coding: utf-8 -*-
#
# Univention Directory Reports
#  module for creating reports about any kind of Univention Admin object
#
# Like what you see? Join us!
# https://www.univention.com/about-us/careers/vacancies/
#
# Copyright 2007-2024 Univention GmbH
#
# https://www.univention.de/
#
# All rights reserved.
#
# The source code of this program is made available
# under the terms of the GNU Affero General Public License version 3
# (GNU AGPL V3) as published by the Free Software Foundation.
#
# Binary versions of this program provided by Univention to you as
# well as other copyrighted, protected or trademarked materials like
# Logos, graphics, fonts, specific documentations and configurations,
# cryptographic keys etc. are subject to a license agreement between
# you and Univention and not subject to the GNU AGPL V3.
#
# In the case you use this program under the terms of the GNU AGPL V3,
# the program is provided in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License with the Debian GNU/Linux or Univention distribution in file
# /usr/share/common-licenses/AGPL-3; if not, see
# <https://www.gnu.org/licenses/>.


from univention.directory.reports.admin import cache_object, connect, connected, get_object, identify, set_format
from univention.directory.reports.config import Config
from univention.directory.reports.document import Document
from univention.directory.reports.error import ReportError
from univention.directory.reports.report import Report


__all__ = ['Config', 'Document', 'Report', 'ReportError', 'cache_object', 'connect', 'connected', 'get_object', 'identify', 'set_format']
